from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="MaxDaysRule7ParametersSpec")


@_attrs_define
class MaxDaysRule7ParametersSpec:
    """
    Attributes:
        max_days (Union[Unset, float]): Maximum accepted value for the actual_value returned by the sensor (inclusive).
    """

    max_days: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        max_days = self.max_days

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if max_days is not UNSET:
            field_dict["max_days"] = max_days

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        max_days = d.pop("max_days", UNSET)

        max_days_rule_7_parameters_spec = cls(
            max_days=max_days,
        )

        max_days_rule_7_parameters_spec.additional_properties = d
        return max_days_rule_7_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.collect_statistics_queue_job_result import (
    CollectStatisticsQueueJobResult,
)
from ...models.statistics_collector_search_filters import (
    StatisticsCollectorSearchFilters,
)
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    json_body: StatisticsCollectorSearchFilters,
    job_business_key: Union[Unset, None, str] = UNSET,
    samples_limit: Union[Unset, None, int] = UNSET,
    configure_table: Union[Unset, None, bool] = UNSET,
    wait: Union[Unset, None, bool] = UNSET,
    wait_timeout: Union[Unset, None, int] = UNSET,
) -> Dict[str, Any]:

    pass

    params: Dict[str, Any] = {}
    params["jobBusinessKey"] = job_business_key

    params["samplesLimit"] = samples_limit

    params["configureTable"] = configure_table

    params["wait"] = wait

    params["waitTimeout"] = wait_timeout

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": "api/jobs/collectstatistics/withgrouping",
        "json": json_json_body,
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[CollectStatisticsQueueJobResult]:
    if response.status_code == HTTPStatus.OK:
        response_200 = CollectStatisticsQueueJobResult.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[CollectStatisticsQueueJobResult]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: StatisticsCollectorSearchFilters,
    job_business_key: Union[Unset, None, str] = UNSET,
    samples_limit: Union[Unset, None, int] = UNSET,
    configure_table: Union[Unset, None, bool] = UNSET,
    wait: Union[Unset, None, bool] = UNSET,
    wait_timeout: Union[Unset, None, int] = UNSET,
) -> Response[CollectStatisticsQueueJobResult]:
    """collectStatisticsOnDataGroups

     Starts a new background job that will run selected data statistics collectors on tables, calculating
    separate metric for each data grouping

    Args:
        job_business_key (Union[Unset, None, str]):
        samples_limit (Union[Unset, None, int]):
        configure_table (Union[Unset, None, bool]):
        wait (Union[Unset, None, bool]):
        wait_timeout (Union[Unset, None, int]):
        json_body (StatisticsCollectorSearchFilters):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[CollectStatisticsQueueJobResult]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        job_business_key=job_business_key,
        samples_limit=samples_limit,
        configure_table=configure_table,
        wait=wait,
        wait_timeout=wait_timeout,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    json_body: StatisticsCollectorSearchFilters,
    job_business_key: Union[Unset, None, str] = UNSET,
    samples_limit: Union[Unset, None, int] = UNSET,
    configure_table: Union[Unset, None, bool] = UNSET,
    wait: Union[Unset, None, bool] = UNSET,
    wait_timeout: Union[Unset, None, int] = UNSET,
) -> Optional[CollectStatisticsQueueJobResult]:
    """collectStatisticsOnDataGroups

     Starts a new background job that will run selected data statistics collectors on tables, calculating
    separate metric for each data grouping

    Args:
        job_business_key (Union[Unset, None, str]):
        samples_limit (Union[Unset, None, int]):
        configure_table (Union[Unset, None, bool]):
        wait (Union[Unset, None, bool]):
        wait_timeout (Union[Unset, None, int]):
        json_body (StatisticsCollectorSearchFilters):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        CollectStatisticsQueueJobResult
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
        job_business_key=job_business_key,
        samples_limit=samples_limit,
        configure_table=configure_table,
        wait=wait,
        wait_timeout=wait_timeout,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: StatisticsCollectorSearchFilters,
    job_business_key: Union[Unset, None, str] = UNSET,
    samples_limit: Union[Unset, None, int] = UNSET,
    configure_table: Union[Unset, None, bool] = UNSET,
    wait: Union[Unset, None, bool] = UNSET,
    wait_timeout: Union[Unset, None, int] = UNSET,
) -> Response[CollectStatisticsQueueJobResult]:
    """collectStatisticsOnDataGroups

     Starts a new background job that will run selected data statistics collectors on tables, calculating
    separate metric for each data grouping

    Args:
        job_business_key (Union[Unset, None, str]):
        samples_limit (Union[Unset, None, int]):
        configure_table (Union[Unset, None, bool]):
        wait (Union[Unset, None, bool]):
        wait_timeout (Union[Unset, None, int]):
        json_body (StatisticsCollectorSearchFilters):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[CollectStatisticsQueueJobResult]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        job_business_key=job_business_key,
        samples_limit=samples_limit,
        configure_table=configure_table,
        wait=wait,
        wait_timeout=wait_timeout,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    json_body: StatisticsCollectorSearchFilters,
    job_business_key: Union[Unset, None, str] = UNSET,
    samples_limit: Union[Unset, None, int] = UNSET,
    configure_table: Union[Unset, None, bool] = UNSET,
    wait: Union[Unset, None, bool] = UNSET,
    wait_timeout: Union[Unset, None, int] = UNSET,
) -> Optional[CollectStatisticsQueueJobResult]:
    """collectStatisticsOnDataGroups

     Starts a new background job that will run selected data statistics collectors on tables, calculating
    separate metric for each data grouping

    Args:
        job_business_key (Union[Unset, None, str]):
        samples_limit (Union[Unset, None, int]):
        configure_table (Union[Unset, None, bool]):
        wait (Union[Unset, None, bool]):
        wait_timeout (Union[Unset, None, int]):
        json_body (StatisticsCollectorSearchFilters):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        CollectStatisticsQueueJobResult
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
            job_business_key=job_business_key,
            samples_limit=samples_limit,
            configure_table=configure_table,
            wait=wait,
            wait_timeout=wait_timeout,
        )
    ).parsed



from typing import Any, Dict, List, Type, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="AllChecksPatchParametersSelectedTablesToColumns")


@_attrs_define
class AllChecksPatchParametersSelectedTablesToColumns:
    """List of concrete table and column names which will be the target. Column mappings are ignored for table level
    checks. This filter is applied at the end.

    """

    additional_properties: Dict[str, List[str]] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:

        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop

        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        all_checks_patch_parameters_selected_tables_to_columns = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = cast(List[str], prop_dict)

            additional_properties[prop_name] = additional_property

        all_checks_patch_parameters_selected_tables_to_columns.additional_properties = (
            additional_properties
        )
        return all_checks_patch_parameters_selected_tables_to_columns

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> List[str]:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: List[str]) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.data_grouping_configuration_spec import DataGroupingConfigurationSpec


T = TypeVar("T", bound="TableSpecGroupings")


@_attrs_define
class TableSpecGroupings:
    """Data grouping configurations list. Data grouping configurations are configured in two cases: (1) the data in the
    table should be analyzed with a GROUP BY condition, to analyze different datasets using separate time series, for
    example a table contains data from multiple countries and there is a 'country' column used for partitioning. (2) a
    tag is assigned to a table (within a data grouping level hierarchy), when the data is segmented at a table level
    (similar tables store the same information, but for different countries, etc.).

    """

    additional_properties: Dict[str, "DataGroupingConfigurationSpec"] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> Dict[str, Any]:
        pass

        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.data_grouping_configuration_spec import (
            DataGroupingConfigurationSpec,
        )

        d = src_dict.copy()
        table_spec_groupings = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = DataGroupingConfigurationSpec.from_dict(prop_dict)

            additional_properties[prop_name] = additional_property

        table_spec_groupings.additional_properties = additional_properties
        return table_spec_groupings

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> "DataGroupingConfigurationSpec":
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: "DataGroupingConfigurationSpec") -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.histogram_daily_issues_count import HistogramDailyIssuesCount


T = TypeVar("T", bound="IssueHistogramModelDays")


@_attrs_define
class IssueHistogramModelDays:
    """A map of the numbers of data quality issues per day, the day uses the DQOps server timezone."""

    additional_properties: Dict[str, "HistogramDailyIssuesCount"] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> Dict[str, Any]:
        pass

        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.histogram_daily_issues_count import HistogramDailyIssuesCount

        d = src_dict.copy()
        issue_histogram_model_days = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = HistogramDailyIssuesCount.from_dict(prop_dict)

            additional_properties[prop_name] = additional_property

        issue_histogram_model_days.additional_properties = additional_properties
        return issue_histogram_model_days

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> "HistogramDailyIssuesCount":
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: "HistogramDailyIssuesCount") -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
